/************************************************************************/
/*                                                                      */
/*    Pmod SSR Demo Project                                             */
/*                                                                      */
/************************************************************************/
/*                                                                      */
/*  Author: Arthur Brown                                                */
/*  Copyright 2017, Digilent Inc.                                       */
/*                                                                      */
/************************************************************************/
/*                                                                      */
/*  File Description:                                                   */
/* This file implements a simple demo application that demonstrates     */
/* how to setup and use the PmodSSR.                                    */
/*                                                                      */
/*  Functionality:                                                      */
/* The Solid State Relay is controlled with Button 1.                   */
/* Whenever Button 1 is pressed, toggles the ON pin of the SSR          */
/* If the SSR is open, close it, if the SSR is closed, open it.         */
/*                                                                      */
/*  Required Hardware:                                                  */
/*    1. Chipkit based Microcontroller                                  */
/*    2. Pmod SSR                                                       */
/*                                                                      */
/*  This demo was tested with the JA port on the chipKit Pro MX4        */
/*                                                                      */
/************************************************************************/
/*                                                                      */
/*  Revision History:                                                   */
/*                                                                      */
/*  1/11/2017(ArtVVB): Created                                          */
/*                                                                      */
/************************************************************************/

// pin locations for chipKit Pro MX4
const int SSR_ON_pin = 0; // JA01 - first pin top row of Pmod header JA
const int BTN1_pin = 42; // onboard button 1

void setup() {
  pinMode(BTN1_pin, INPUT);
  pinMode(SSR_ON_pin, OUTPUT);
  digitalWrite(SSR_ON_pin, LOW);
}
int ssr_state = 0; // current opened/closed  status of switch
int last_btn = LOW; // previous status of the button, used to evaluate transitions
void loop() {
  int btn = digitalRead(BTN1_pin);
  if (btn == HIGH && last_btn == LOW) { // whenever the button is pressed
    for (int i=0; i < 65536; i++) // debounce the transition
      if (digitalRead(BTN1_pin) == LOW)
        return; // don't update last_btn to btn, has gone low again
    if (ssr_state == LOW) { // toggle the opened/closed state of the SSR
      ssr_state = HIGH;
    }
    else {
      ssr_state = LOW;
    }
    digitalWrite(SSR_ON_pin, ssr_state);
  }
  last_btn = btn;
}
